@@ -11,15 +11,12 @@
 #include "korganizerinterface.h"
 #include "todoplugin.h"
 #include <CalendarSupport/CalendarSingleton>
-#include <kcalendarcore_version.h>
 
 #include <Akonadi/CalendarUtils>
 #include <Akonadi/Collection>
 #include <Akonadi/IncidenceChanger>
 #include <Akonadi/ItemFetchScope>
 
-#include <KCalUtils/IncidenceFormatter>
-
 #include <KontactInterface/Core>
 
 #include <KConfig>
@@ -34,8 +31,6 @@
 #include <QTextDocument> // for Qt::mightBeRichText
 #include <QVBoxLayout>
 
-using namespace KCalUtils;
-
 TodoSummaryWidget::TodoSummaryWidget(TodoPlugin *plugin, QWidget *parent)
     : KontactInterface::Summary(parent)
     , mPlugin(plugin)
@@ -126,18 +121,12 @@ void TodoSummaryWidget::updateView()
         prList.append(todo);
     }
     if (!prList.isEmpty()) {
-#if KCALENDARCORE_VERSION < QT_VERSION_CHECK(5, 95, 0)
-        prList = Akonadi::ETMCalendar::sortTodos(prList, KCalendarCore::TodoSortSummary, KCalendarCore::SortDirectionAscending);
-        prList = Akonadi::ETMCalendar::sortTodos(prList, KCalendarCore::TodoSortPriority, KCalendarCore::SortDirectionAscending);
-        prList = Akonadi::ETMCalendar::sortTodos(prList, KCalendarCore::TodoSortDueDate, KCalendarCore::SortDirectionAscending);
-#else
         KCalendarCore::Todo::List todoListSorted1(prList);
         KCalendarCore::Todo::List todoListSorted2(prList);
         KCalendarCore::Todo::List todoListSorted3(prList);
         prList = Akonadi::ETMCalendar::sortTodos(std::move(todoListSorted1), KCalendarCore::TodoSortSummary, KCalendarCore::SortDirectionAscending);
         prList = Akonadi::ETMCalendar::sortTodos(std::move(todoListSorted2), KCalendarCore::TodoSortPriority, KCalendarCore::SortDirectionAscending);
         prList = Akonadi::ETMCalendar::sortTodos(std::move(todoListSorted3), KCalendarCore::TodoSortDueDate, KCalendarCore::SortDirectionAscending);
-#endif
     }
 
     // The to-do print consists of the following fields:
