@@ -8,6 +8,7 @@
 */
 
 #pragma once
+#include "kcmutils_version.h"
 #include "kprefsdialog.h"
 #include <QWidget>
 
@@ -22,7 +23,11 @@ class KOPrefsDialogColorsAndFonts : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
-    explicit KOPrefsDialogColorsAndFonts(QWidget *parent, const QVariantList &args);
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
+    explicit KOPrefsDialogColorsAndFonts(QWidget *parent, const QVariantList &args = {});
+#else
+    explicit KOPrefsDialogColorsAndFonts(QObject *parent, const KPluginMetaData &data, const QVariantList &args = {});
+#endif
 
 protected:
     void usrWriteConfig() override;
